# linkedin-discord-bot

[![ci](https://github.com/IAmSkweetis/linkedin-discord-bot/actions/workflows/ci.yml/badge.svg?branch=main)](https://github.com/IAmSkweetis/linkedin-discord-bot/actions/workflows/ci.yml)

A simple little discord bot that will search LinkedIn job postings daily at post them to discord.

Features:
- [x] Persistent DB - Stores Job Queries and Past Jobs
- [x] CLI
- [ ] Discord Integration

## Installation

The current implementation of the bot runs locally. PyPi and/or containerization to be provided soon.

For now, follow the setup instructions.

## Usage

In the current iteration, the bot is CLI only and can be run via uv (or within the virtual env generated by uv).

```bash
uv run lidb
```


## Dev Setup

Requirements:
- [uv](https://docs.astral.sh/uv/)
- [Taskfile](https://taskfile.dev/)
- sqlite3

Clone the repo:
```bash
git clone git@github.com:IAmSkweetis/linkedin-discord-bot.git
```

Use uv to sync:
```bash
uv sync
```

Run the following scripts for local-dev setup:
```bash
# Install chromedriver
task setup:chromedriver

# Initialize the local db
task db:init

# Run any db migrations
task db:migrate
```
